@@ -3,11 +3,13 @@ import React from 'react'
 import mlib from 'ssb-msgs'
 import threadlib from 'patchwork-threads'
 import clipboard from 'clipboard'
+import onImageLoaded from 'image-loaded'
+import multicb from 'multicb'
 import { MsgLink, UserLink, UserLinks, UserPic, NiceDate } from '../index'
 import { Block as Content } from '../msg-content'
 import { Inline as MdInline } from '../markdown'
-import { ModalContainer } from '../modals'
-import { FlagMsgForm } from '../forms'
+import Modal from '../modals/single'
+import FlagMsgForm from '../forms/flag-msg'
 import { countReplies } from '../../lib/msg-relation'
 import DropdownBtn from '../dropdown'
 import u from '../../lib/util'
@@ -128,10 +130,16 @@ export default class Card extends React.Component {
     // is the card oversized?
     if (!this.refs.body)
       return
-    const rect = this.refs.body.getClientRects()[0]
-    if (rect && rect.height > MAX_CONTENT_HEIGHT) {
-      this.setState({ isOversized: true })
-    }
+    // wait for images to finish loading
+    var done = multicb()
+    Array.from(this.refs.body.querySelectorAll('img')).forEach(el => onImageLoaded(el, done()))
+    done(() => {
+      // check height
+      const rect = this.refs.body.getClientRects()[0]
+      if (rect && rect.height > MAX_CONTENT_HEIGHT) {
+        this.setState({ isOversized: true })
+      }
+    })
   }
 
   componentWillUnmount() {
@@ -255,9 +263,7 @@ export default class Card extends React.Component {
           { !this.props.noReplies ? <div><a onClick={this.onSelect.bind(this)}><i className="fa fa-reply" /> Reply</a></div> : '' }
         </div>
       </div>
-      <ModalContainer isOpen={this.state.isFlagModalOpen} onRequestClose={this.onCloseFlagModal.bind(this)}>
-        <FlagMsgForm msg={msg} onSubmit={this.onSubmitFlag.bind(this)} />
-      </ModalContainer>
+      <Modal isOpen={this.state.isFlagModalOpen} onClose={this.onCloseFlagModal.bind(this)} Form={FlagMsgForm} formProps={{msg: msg, onSubmit: this.onSubmitFlag.bind(this)}} nextLabel="Publish" />
     </div>
   }
 }
\ No newline at end of file
